NavigationItem class

Model representing a navigation item for CustomBottomBar.

Each NavigationItem defines the icon, selected icon, label, and an optional badge count to be displayed in the navigation bar.

Example:

NavigationItem(
  icon: Icons.home_outlined,
  selectedIcon: Icons.home,
  label: 'Home',
  badgeCount: 3,
)
  • icon: Icon to display when the item is not selected.
  • selectedIcon: Icon to display when the item is selected.
  • label: Label for the navigation item.
  • badgeCount: Optional badge count to display on the item (e.g., for notifications).

Constructors

Creates a NavigationItem.
const

Properties

badgeCount int?
Optional badge count to display on the item (e.g., for notifications).
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
The icon to display when the item is not selected.
final
label String
The label for the navigation item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon IconData
The icon to display when the item is selected.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited