MkxThemeData class
Custom theme data class for MkxTheme
This class provides a way to customize specific aspects of a theme without having to specify all theme properties. It's used with MkxTheme.applyCustomTheme to create customized themes.
Basic example:
// Create custom theme data with purple color scheme
final customThemeData = MkxThemeData(
colorScheme: ColorScheme.fromSeed(
seedColor: Colors.purple,
brightness: Brightness.light,
),
);
// Apply to light theme
final customTheme = MkxTheme.applyCustomTheme(
MkxTheme.light,
customThemeData,
);
// Use in MaterialApp
MaterialApp(
theme: customTheme,
// ...
)
Constructors
- MkxThemeData({ColorScheme? colorScheme, InputDecorationTheme? inputDecorationTheme, ElevatedButtonThemeData? elevatedButtonTheme})
-
Creates an MkxThemeData with optional theme customizations
const
Properties
- colorScheme → ColorScheme?
-
The color scheme for the theme
final
- elevatedButtonTheme → ElevatedButtonThemeData?
-
Elevated button theme
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDecorationTheme → InputDecorationTheme?
-
Input decoration theme for text fields
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ColorScheme? colorScheme, InputDecorationTheme? inputDecorationTheme, ElevatedButtonThemeData? elevatedButtonTheme}) → MkxThemeData - Creates a copy of this MkxThemeData with the given fields replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited