MkxThemeData constructor
const
MkxThemeData({
- ColorScheme? colorScheme,
- InputDecorationTheme? inputDecorationTheme,
- ElevatedButtonThemeData? elevatedButtonTheme,
Creates an MkxThemeData with optional theme customizations
All parameters are optional and will only override the corresponding properties in the base theme when applied with MkxTheme.applyCustomTheme.
Example:
// Create a theme with custom input decoration
final customThemeData = MkxThemeData(
inputDecorationTheme: InputDecorationTheme(
filled: true,
fillColor: Colors.grey[100],
border: OutlineInputBorder(
borderRadius: BorderRadius.circular(10),
),
),
);
Implementation
const MkxThemeData({
this.colorScheme,
this.inputDecorationTheme,
this.elevatedButtonTheme,
});