CustomChip class
A customizable chip widget for displaying compact information
This widget provides a styled chip that can be used for tags, filters, or other compact information displays with optional delete functionality.
Basic example:
CustomChip(
label: 'Flutter',
)
With delete functionality:
CustomChip(
label: 'React',
onDeleted: () {
setState(() {
_tags.remove('React');
});
},
backgroundColor: Colors.blue[100],
labelColor: Colors.blue[800],
)
Using with a list of tags:
Wrap(
spacing: 8.0,
children: _tags.map((tag) {
return CustomChip(
label: tag,
onDeleted: () {
setState(() {
_tags.remove(tag);
});
},
);
}).toList(),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CustomChip
Constructors
- CustomChip({Key? key, required String label, VoidCallback? onDeleted, Color? backgroundColor, Color? labelColor, IconData? avatar})
-
Creates a CustomChip with the required
labeland optional parametersconst
Properties
- avatar → IconData?
-
Optional icon to display as an avatar
final
- backgroundColor → Color?
-
Optional background color override
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
The text label to display in the chip
final
- labelColor → Color?
-
Optional label text color override
final
- onDeleted → VoidCallback?
-
Optional callback when the delete icon is tapped
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited